GovAPI class

Inheritance

Constructors

GovAPI(TerraRestfulService apiRequester)

Properties

apiRequester → TerraRestfulService
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDepositParams() → Future<ProposalsDepositParams>
getProposal(double proposalID) → Future<Proposal>
getProposals({ProposalStatus status = ProposalStatus.ProposalStatusUnspecified}) → Future<List<Proposal>>
getTally(double proposalID) → Future<FinalTallyResult>
getTallyParams() → Future<ProposalsTallyParams>
getVotingParams() → Future<ProposalsVotesParams>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited