MarketAPI class

Inheritance

Constructors

MarketAPI(TerraRestfulService apiRequester)

Properties

apiRequester → TerraRestfulService
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMarketingParameters() → Future<MarketingParamsValueApi>
getPoolDelta() → Future<double>
getSwapRate(Coin offerCoin, String askDenom) → Future<Coin>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited