TendermintAPI class

Inheritance

Constructors

TendermintAPI(TerraRestfulService apiRequester)

Properties

apiRequester → TerraRestfulService
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBlockInfo({int? height}) → Future<BlockContainer>
getNodeInfo() → Future<NodeInfoCommonJSON>
getSyncing() → Future<bool>
getValidatorSet({double? height}) → Future<List<TendermintValidators>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited