BaseAccount class

Implemented types

Constructors

BaseAccount(String? address, KeysDto? publicKey, double? accountNumber, double? sequence)

Properties

accountNumber → double?
final
address → String?
final
hashCode → int
The hash code for this object.
no setterinherited
publicKey → KeysDto?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence → double?
final

Methods

getAccountNumber() → double
override
getPublicKey() → KeysDto
override
getSequenceNumber() → double
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → BaseAccountAminoArgs
ToData() → BaseAccountDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited