BaseAccountDataArgs class

Inheritance

Constructors

BaseAccountDataArgs({dynamic type = CosmosConstants.COSMOS_AUTH})

Properties

account_number ↔ String?
getter/setter pairinherited
address ↔ String?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
public_key ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence ↔ String?
getter/setter pairinherited
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited