Input class

Constructors

Input(String address, List<Coin> coins)

Properties

address → String
final
coins → List<Coin>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → InputAminoArgs
toData() → InputDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAmino(InputAminoArgs data) → Input
fromData(InputDataArgs data) → Input