MsgMultiSend class

Constructors

MsgMultiSend(List<Input> inputs, List<Output> outputs)

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputs ↔ List<Input>
getter/setter pair
outputs ↔ List<Output>
getter/setter pair
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → MsgMultiSendAminoArgs
toArray() → List<SignerData>
inherited
toData() → MsgMultiSendDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited