MsgConnectionOpenInit class

Constructors

MsgConnectionOpenInit(String client_id, Counterparty counterparty, Version version, double delay_period, String signer)

Properties

client_id → String
final
counterparty → Counterparty
final
delay_period → double
final
hashCode → int
The hash code for this object.
no setterinherited
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited
signer → String
final
version → Version
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArray() → List<SignerData>
inherited
toData() → MsgConnectionOpenInitDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited