MsgConnectionOpenInitDataArgs class

Properties

client_id ↔ String?
getter/setter pair
counterparty ↔ CounterpartyDataArgs?
getter/setter pair
delay_period ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signer ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair
version ↔ VersionDataArgs?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited