MsgConnectionOpenTry class

Constructors

MsgConnectionOpenTry(String client_id, String previous_connection_id, Any client_state, Counterparty counterparty, List<Version> counterparty_versions, double delay_period, Height proof_height, String proof_init, String proof_client, String proof_consensus, Height consensus_height, String signer)

Properties

client_id → String
final
client_state → Any
final
consensus_height → Height
final
counterparty → Counterparty
final
counterparty_versions → List<Version>
final
delay_period → double
final
hashCode → int
The hash code for this object.
no setterinherited
previous_connection_id → String
final
proof_client → String
final
proof_consensus → String
final
proof_height → Height
final
proof_init → String
final
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited
signer → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArray() → List<SignerData>
inherited
toData() → MsgConnectionOpenTryDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited