MsgAggregateExchangeRateVote class

Constructors

MsgAggregateExchangeRateVote(String salt, String feeder, String validator, String exchange_rates)

Properties

exchange_rates → String
final
feeder → String
final
hashCode → int
The hash code for this object.
no setterinherited
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salt → String
final
sequenceNumber ↔ double?
getter/setter pairinherited
validator → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → MsgAggregateExchangeRateVoteAminoArgs
toArray() → List<SignerData>
inherited
toData() → MsgAggregateExchangeRateVoteDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited