SoftwareUpgradeProposal class

Constructors

SoftwareUpgradeProposal(String title, String description, Plan? plan)

Properties

description → String
final
hashCode → int
The hash code for this object.
no setterinherited
plan → Plan?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → SoftwareUpgradeProposalAminoArgs
toData() → SoftwareUpgradeProposalDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited